pyscenarios: Python Scenario Generator
======================================

.. toctree::

   installing
   whats-new

API Reference
-------------

.. toctree::

   api/copula
   api/sobol
   api/stats

License
-------

pyscenarios is available under the open source `LGPL License`__.

__ https://www.gnu.org/licenses/lgpl-3.0.en.html
